@@ -55,8 +55,10 @@ __all__ = [
     "indtc",
     "iowa",
     "iowactapp",
-    "kan",
-    "kanctapp",
+    "kan_p",
+    "kan_u",
+    "kanctapp_p",
+    "kanctapp_u",
     "ky",
     "la",
     "mass",
