@@ -9,8 +9,7 @@ from juriscraper.opinions.united_states.state import nyappterm_1st
 
 
 class Site(nyappterm_1st.Site):
-
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
-        self.court = 'Appellate+Term,+2d+Dept'
-        self.parameters.update({'court': self.court})
\ No newline at end of file
+        self.court = "Appellate+Term,+2d+Dept"
+        self.parameters.update({"court": self.court})
