@@ -9,48 +9,40 @@ Date created: 2013-08-10
 
 import re
 from datetime import datetime
-
-from juriscraper.OpinionSite import OpinionSite
+from juriscraper.OpinionSiteLinear import OpinionSiteLinear
 from juriscraper.lib.exceptions import InsanityException
-from juriscraper.lib.string_utils import convert_date_string
 
 
-class Site(OpinionSite):
+class Site(OpinionSiteLinear):
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
         self.court_id = self.__module__
-        self.base_url = "http://www.courts.ri.gov/Courts/SupremeCourt/Pages/Opinions/Opinions"
-        self.url = self.build_url()
-        self.cases = []
+        self.url = self.build_url(
+            "https://www.courts.ri.gov/Courts/SupremeCourt/Pages/Opinions/Opinions"
+        )
         self.previous_date = None
         self.include_summary = True
-        self.precedential_status = "Published"
+        self.status = "Published"
 
         # HTTPS certificate is bad, but hopefully they'll fix it and we can remove the line below
         self.disable_certificate_verification()
 
-    def build_url(self):
+    def build_url(self, base_url):
         # This court hears things from mid-September to end of June. This
         # defines the "term" for that year, which triggers the website updates.
         today = datetime.today()
-        if today >= datetime(today.year, 9, 15):
-            year = today.year
-        else:
-            year = today.year - 1
-        return "%s%d-%d.aspx" % (self.base_url, year, year + 1)
+        this_year = today.year
+        term_end = datetime(this_year, 9, 15)
+        year = this_year if today >= term_end else this_year - 1
+        return "%s%d-%d.aspx" % (base_url, year, year + 1)
 
-    def _download(self, request_dict={}):
-        html = super(Site, self)._download(request_dict)
-        self.extract_cases_from_html(html)
-        return html
-
-    def extract_cases_from_html(self, html):
+    def _process_html(self):
         # case information spans over 3 rows, so must process 3 at a time:
         #   <tr> - contains case name, docket number, date and pdf link
         #   <tr> - contains case summary
         #   <tr> - contains a one-pixel gif spacer
         table = "//table[@id = 'onetidDoclibViewTbl0']/tr[position() > 1]"
-        rows = list(html.xpath(table))
+        rows = list(self.html.xpath(table))
         row_triplets = list(zip(rows, rows[1:]))[::3]
 
         for tr1, tr2 in row_triplets:
@@ -86,7 +78,7 @@ class Site(OpinionSite):
         for text in text_list:
             date_match = re.match(regex, text)
             if date_match:
-                return convert_date_string(date_match.group(3))
+                return date_match.group(3)
 
         # Fall back on previous case's date
         if self.previous_date:
@@ -124,21 +116,3 @@ class Site(OpinionSite):
         raise InsanityException(
             'Could not parse name from string: "%s"' % text_list
         )
-
-    def _get_case_names(self):
-        return [case["name"] for case in self.cases]
-
-    def _get_download_urls(self):
-        return [case["url"] for case in self.cases]
-
-    def _get_case_dates(self):
-        return [case["date"] for case in self.cases]
-
-    def _get_precedential_statuses(self):
-        return [self.precedential_status] * len(self.cases)
-
-    def _get_docket_numbers(self):
-        return [case["docket"] for case in self.cases]
-
-    def _get_summaries(self):
-        return [case["summary"] for case in self.cases]
