@@ -5,8 +5,8 @@ class Site(wash.Site):
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
         self.court_id = self.__module__
-        self.courtLevel = 'C'
-        self.pubStatus = 'PUB'
+        self.courtLevel = "C"
+        self.pubStatus = "PUB"
         self._set_parameters()
 
     def _get_case_names(self):
