@@ -16,7 +16,7 @@ class Site(OralArgumentSite):
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
         self.court_id = self.__module__
-        self.url = 'http://www.ca5.uscourts.gov/rss.aspx?Feed=OralArgRecs'
+        self.url = "http://www.ca5.uscourts.gov/rss.aspx?Feed=OralArgRecs"
 
     def _get_download_urls(self):
         path = "//item/link"
@@ -28,8 +28,10 @@ class Site(OralArgumentSite):
 
     def _get_case_dates(self):
         path = "//item/description/text()[3]"
-        return [datetime.strptime(date_string[9:], '%m/%d/%Y').date() for
-                date_string in self.html.xpath(path)]
+        return [
+            datetime.strptime(date_string[9:], "%m/%d/%Y").date()
+            for date_string in self.html.xpath(path)
+        ]
 
     def _get_docket_numbers(self):
         path = "//item/description/text()[1]"
