@@ -8,12 +8,20 @@ from lxml.html import tostring
 
 from .docket_report import BaseDocketReport
 from .reports import BaseReport
-from .utils import clean_pacer_object, get_court_id_from_url, \
-    get_pacer_doc_id_from_doc1_url, is_pdf
+from .utils import (
+    get_court_id_from_url,
+    get_pacer_doc_id_from_doc1_url,
+    is_pdf,
+)
 from ..lib.judge_parsers import normalize_judge_string
 from ..lib.log_tools import make_default_logger
-from ..lib.string_utils import clean_string, convert_date_string, \
-    force_unicode, harmonize
+from ..lib.string_utils import (
+    clean_string,
+    convert_date_string,
+    force_unicode,
+    harmonize,
+)
+from ..lib.utils import clean_court_object
 
 logger = make_default_logger()
 
@@ -29,22 +37,23 @@ class AppellateDocketReport(BaseDocketReport, BaseReport):
     """
 
     docket_number_dist_regex = re.compile(
-        r"((\d{1,2}:)?\d\d-[a-zA-Z]{1,4}-\d{1,10})")
+        r"((\d{1,2}:)?\d\d-[a-zA-Z]{1,4}-\d{1,10})"
+    )
 
-    CACHE_ATTRS = ['metadata', 'docket_entries']
+    CACHE_ATTRS = ["metadata", "docket_entries"]
 
     ERROR_STRINGS = BaseReport.ERROR_STRINGS + [
-        r'The link to this page may not have originated from within CM/ECF.',
+        r"The link to this page may not have originated from within CM/ECF.",
         r'Click on the "Accept Charges and Retrieve" button ONCE at the '
-        r'bottom of this page to download the document image.',
+        r"bottom of this page to download the document image.",
         r'<embed width="100%" height="100%" name="plugin" id="plugin"',
-        r'Access to the document you are about to view has been restricted.*'
-        r'Do not allow it to be seen by unauthorized persons.',
+        r"Access to the document you are about to view has been restricted.*"
+        r"Do not allow it to be seen by unauthorized persons.",
         r'document.location\s*=\s*"https://pacer.login.uscourts.gov',
         r'http-equiv="REFRESH"',
-        r'Case Number Not Found</b>',
-        r'<title>404 Not Found</title>',
-        r'<b>\d+ Documents are attached to this filing</b>',
+        r"Case Number Not Found</b>",
+        r"<title>404 Not Found</title>",
+        r"<b>\d+ Documents are attached to this filing</b>",
     ]
 
     def __init__(self, court_id, pacer_session=None):
@@ -57,21 +66,36 @@ class AppellateDocketReport(BaseDocketReport, BaseReport):
 
     @property
     def url(self):
-        if self.court_id == 'psc':
-            return "https://dcecf.psc.uscourts.gov/" \
-                   "n/beam/servlet/TransportRoom"
-        elif self.court_id in ['ca5', 'ca7', 'ca11']:
-            return "https://ecf.%s.uscourts.gov/" \
-                   "cmecf/servlet/TransportRoom" % self.court_id
+        if self.court_id == "psc":
+            return (
+                "https://dcecf.psc.uscourts.gov/"
+                "n/beam/servlet/TransportRoom"
+            )
+        elif self.court_id in ["ca5", "ca7", "ca11"]:
+            return (
+                "https://ecf.%s.uscourts.gov/"
+                "cmecf/servlet/TransportRoom" % self.court_id
+            )
         else:
-            return "https://ecf.%s.uscourts.gov/" \
-                   "n/beam/servlet/TransportRoom" % self.court_id
+            return (
+                "https://ecf.%s.uscourts.gov/"
+                "n/beam/servlet/TransportRoom" % self.court_id
+            )
 
-    def query(self, docket_number, show_docket_entries=False,
-              show_orig_docket=False, show_prior_cases=False,
-              show_associated_cases=False, show_panel_info=False,
-              show_party_atty_info=False, show_caption=False,
-              date_start=None, date_end=None, output_format='html'):
+    def query(
+        self,
+        docket_number,
+        show_docket_entries=False,
+        show_orig_docket=False,
+        show_prior_cases=False,
+        show_associated_cases=False,
+        show_panel_info=False,
+        show_party_atty_info=False,
+        show_caption=False,
+        date_start=None,
+        date_end=None,
+        output_format="html",
+    ):
         """
         Query PACER to get a docket report.
 
@@ -165,52 +189,60 @@ class AppellateDocketReport(BaseDocketReport, BaseReport):
                 All parameters same as above, except...
                 confirmCharge=y <-- Added
         """
-        assert self.session is not None, \
-            u'session attribute of AppellateDocketReport cannot be None.'
-        assert bool(docket_number), \
+        assert (
+            self.session is not None
+        ), u"session attribute of AppellateDocketReport cannot be None."
+        assert bool(docket_number), (
             u'docket_number must be a valid value, not "%s"' % docket_number
+        )
 
         if not show_docket_entries and (date_end or date_start):
-            raise ValueError(u'Cannot set date filtering on docket entries '
-                             u'while show_docket_entries=False')
+            raise ValueError(
+                u"Cannot set date filtering on docket entries "
+                u"while show_docket_entries=False"
+            )
 
-        if output_format.lower() not in [u'xml', u'html']:
+        if output_format.lower() not in [u"xml", u"html"]:
             raise ValueError(u"Invalid value for output_format parameter.")
 
         query_params = {
-            u'servlet': u'CaseSummary.jsp',
-            u'caseNum': docket_number,
+            u"servlet": u"CaseSummary.jsp",
+            u"caseNum": docket_number,
         }
         if show_docket_entries:
-            query_params[u'incDktEntries'] = u'Y'
+            query_params[u"incDktEntries"] = u"Y"
         if show_orig_docket:
-            query_params[u'incOrigDkt'] = u'Y'
+            query_params[u"incOrigDkt"] = u"Y"
         if show_prior_cases:
-            query_params[u'incPrior'] = u'Y'
+            query_params[u"incPrior"] = u"Y"
         if show_associated_cases:
-            query_params[u'incAssoc'] = u'Y'
+            query_params[u"incAssoc"] = u"Y"
         if show_panel_info:
-            query_params[u'incPanel'] = u'Y'
+            query_params[u"incPanel"] = u"Y"
         if show_party_atty_info:
-            query_params[u'incPtyAty'] = u'Y'
+            query_params[u"incPtyAty"] = u"Y"
         if show_caption:
-            query_params[u'incCaption'] = u'long'
+            query_params[u"incCaption"] = u"long"
 
         if date_start:
-            query_params[u'dateFrom'] = date_start.strftime(u'%m/%d/%Y')
+            query_params[u"dateFrom"] = date_start.strftime(u"%m/%d/%Y")
         if date_end:
-            query_params[u'dateTo'] = date_end.strftime(u'%m/%d/%Y')
+            query_params[u"dateTo"] = date_end.strftime(u"%m/%d/%Y")
 
-        if output_format.lower() == u'xml':
-            query_params[u'outputXML_TXT'] = u'XML'
-            query_params[u'confirmCharge'] = u'y'  # Lowercase y.
-        elif output_format.lower() == u'html':
+        if output_format.lower() == u"xml":
+            query_params[u"outputXML_TXT"] = u"XML"
+            query_params[u"confirmCharge"] = u"y"  # Lowercase y.
+        elif output_format.lower() == u"html":
             # When doing HTML, we need to do actionType param.
-            query_params[u'fullDocketReport'] = u'Y'
-            query_params[u'actionType'] = u'Run+Docket+Report'
+            query_params[u"fullDocketReport"] = u"Y"
+            query_params[u"actionType"] = u"Run+Docket+Report"
 
-        logger.info(u"Querying appellate docket report for docket number '%s' "
-                    u"with params %s", docket_number, query_params)
+        logger.info(
+            u"Querying appellate docket report for docket number '%s' "
+            u"with params %s",
+            docket_number,
+            query_params,
+        )
         self.response = self.session.get(self.url, params=query_params)
         self.parse()
 
@@ -271,24 +303,29 @@ class AppellateDocketReport(BaseDocketReport, BaseReport):
         identified and so is ignored below.
         # noqa
         """
-        assert self.session is not None, \
-            u'session attribute of AppellateDocketReport cannot be None.'
+        assert (
+            self.session is not None
+        ), u"session attribute of AppellateDocketReport cannot be None."
         query_params = {
-            u'servlet': u'ShowDoc',
-            u'incPdfHeader': u'Y',
-            u'incPdfHeaderDisp': u'Y',
-            u'dls_id': pacer_doc_id,
-            u'pacer': u't',  # Not sure what this does, but it's required.
+            u"servlet": u"ShowDoc",
+            u"incPdfHeader": u"Y",
+            u"incPdfHeaderDisp": u"Y",
+            u"dls_id": pacer_doc_id,
+            u"pacer": u"t",  # Not sure what this does, but it's required.
         }
         if pacer_case_id:
-            query_params[u'caseId'] = pacer_case_id
-        logger.info(u"GETting PDF at URL: %s with params: %s",
-                    self.url, query_params)
+            query_params[u"caseId"] = pacer_case_id
+        logger.info(
+            u"GETting PDF at URL: %s with params: %s", self.url, query_params
+        )
         r = self.session.get(self.url, params=query_params)
         r.raise_for_status()
         if is_pdf(r):
-            logger.info("Got PDF binary data for document #%s in court %s",
-                        pacer_doc_id, self.court_id)
+            logger.info(
+                "Got PDF binary data for document #%s in court %s",
+                pacer_doc_id,
+                self.court_id,
+            )
             return r
         return None
 
@@ -298,31 +335,28 @@ class AppellateDocketReport(BaseDocketReport, BaseReport):
             return self._metadata
 
         data = {
-            u'court_id': self.court_id,
-            u'docket_number': self._get_tail_by_regex("Docket #|Case Number"),
-            u'case_name': self._get_case_name(),
-            u'panel': self._get_panel(),
-            u'nature_of_suit': self._get_tail_by_regex("Nature of Suit"),
-            u'appeal_from': self._get_tail_by_regex('Appeal From'),
-            u'fee_status': self._get_tail_by_regex('Fee Status'),
-            u'date_filed': self._get_tail_by_regex('Docketed', True),
-            u'date_terminated': self._get_tail_by_regex('Termed', True),
-            u'case_type_information': self._get_case_type_info(),
-            u'originating_court_information':
-                self._get_originating_court_info(),
+            u"court_id": self.court_id,
+            u"docket_number": self._get_tail_by_regex("Docket #|Case Number"),
+            u"case_name": self._get_case_name(),
+            u"panel": self._get_panel(),
+            u"nature_of_suit": self._get_tail_by_regex("Nature of Suit"),
+            u"appeal_from": self._get_tail_by_regex("Appeal From"),
+            u"fee_status": self._get_tail_by_regex("Fee Status"),
+            u"date_filed": self._get_tail_by_regex("Docketed", True),
+            u"date_terminated": self._get_tail_by_regex("Termed", True),
+            u"case_type_information": self._get_case_type_info(),
+            u"originating_court_information": self._get_originating_court_info(),
         }
-        data = clean_pacer_object(data)
+        data = clean_court_object(data)
         self._metadata = data
         return data
 
     # Fields that need to be converted with convert_date_str()
-    PARTY_DATE_FIELDS = [
-        u'Terminated'
-    ]
+    PARTY_DATE_FIELDS = [u"Terminated"]
     # Translation table from Appellate CMECF party fields schema to
     # juriscaper schema.
     PARTY_FIELDS = {
-        u'Terminated': u'date_terminated',
+        u"Terminated": u"date_terminated",
     }
 
     @property
@@ -342,14 +376,16 @@ class AppellateDocketReport(BaseDocketReport, BaseReport):
 
         # Grab the rows of the first nested table
         # following the comment defining this section of the report
-        path = ('//comment()[contains(., "NEW SECTION - Party/Aty List")]/'
-                'following-sibling::table[1]//table//tr')
+        path = (
+            '//comment()[contains(., "NEW SECTION - Party/Aty List")]/'
+            "following-sibling::table[1]//table//tr"
+        )
 
         party_rows = self.tree.xpath(path)
 
         parties = []
         for row in party_rows:
-            cells = row.xpath('.//td')
+            cells = row.xpath(".//td")
             party = {}
 
             # Skip merged cells, such as blank dividers
@@ -368,25 +404,26 @@ class AppellateDocketReport(BaseDocketReport, BaseReport):
 
             name_role = self.redelimit_p(cells[0], self.BR_REGEX)
             count = len(name_role)
-            assert count >= 2, \
-                "Expecting 2+ <br>-delimited portions of first cell."
+            assert (
+                count >= 2
+            ), "Expecting 2+ <br>-delimited portions of first cell."
 
             # Name is first, Role is last
-            party[u'name'] = force_unicode(name_role[0].text_content().strip())
-            role = name_role[count-1].text_content().strip()
+            party[u"name"] = force_unicode(name_role[0].text_content().strip())
+            role = name_role[count - 1].text_content().strip()
             # Strip terminal comma, if present.
-            role = re.sub(r',$', '', role)
-            party[u'type'] = role
+            role = re.sub(r",$", "", role)
+            party[u"type"] = role
 
             unparsed = []
-            for i in range(1, count-1):
+            for i in range(1, count - 1):
                 element = name_role[i]
                 #  <B>Terminated: </B>07/31/2017<BR>
-                bold = element.find('b')
+                bold = element.find("b")
                 if bold is not None:
                     raw_field = bold.text_content().strip()
                     # Remove terminal colon
-                    raw_field = re.sub(r':$', '', raw_field)
+                    raw_field = re.sub(r":$", "", raw_field)
                     # Translate field name to Juriscraper schema, if it exists
                     if raw_field in self.PARTY_FIELDS:
                         field = self.PARTY_FIELDS[raw_field]
@@ -401,12 +438,13 @@ class AppellateDocketReport(BaseDocketReport, BaseReport):
 
                     party[field] = value
                 else:
-                    s = ''.join(
-                        tostring(e, encoding='unicode') for e in element)
+                    s = "".join(
+                        tostring(e, encoding="unicode") for e in element
+                    )
                     unparsed.append(s)
 
             if unparsed:
-                party[u'unparsed'] = unparsed
+                party[u"unparsed"] = unparsed
 
             attorneys = cells[1]
 
@@ -457,8 +495,9 @@ class AppellateDocketReport(BaseDocketReport, BaseReport):
 
             # We fixup the raw HTML by separating attorneys into <p>
             # elements, replacing <br><br> pairs.
-            attorney_rows = self.redelimit_p(attorneys,
-                                             r'(?i)<br\s*/?><br\s*/?>')
+            attorney_rows = self.redelimit_p(
+                attorneys, r"(?i)<br\s*/?><br\s*/?>"
+            )
             attorneys = []
             for attorney_row in attorney_rows:
                 attorney = {}
@@ -467,23 +506,23 @@ class AppellateDocketReport(BaseDocketReport, BaseReport):
                 # it's a bit wasteful to use both.
                 attorney_lines = self._br_split(attorney_row)
                 # First line is the name
-                attorney[u'name'] = attorney_lines.pop(0)
-                if not attorney[u'name']:
+                attorney[u"name"] = attorney_lines.pop(0)
+                if not attorney[u"name"]:
                     continue
                 roles = []
                 contacts = []
                 for attorney_line in attorney_lines:
                     # [Bracketted] lines are roles, others are contacts.
-                    m = re.match(r'\[(.*)\]', attorney_line)
+                    m = re.match(r"\[(.*)\]", attorney_line)
                     if m:
                         roles.append(m.group(1))
                     else:
                         contacts.append(attorney_line)
-                attorney[u'roles'] = roles
-                attorney[u'contact'] = u'\n'.join(contacts)
+                attorney[u"roles"] = roles
+                attorney[u"contact"] = u"\n".join(contacts)
                 attorneys.append(attorney)
 
-            party[u'attorneys'] = attorneys
+            party[u"attorneys"] = attorneys
             parties.append(party)
 
         parties = self._normalize_see_above_attorneys(parties)
@@ -500,43 +539,45 @@ class AppellateDocketReport(BaseDocketReport, BaseReport):
         # If "View Multiple Documents" is checked, there's a form, if not, it's
         # a table. Thus, find all the trs below the first table or form after
         # the comment.
-        path = ('//comment()[contains(., "DOCKET ENTRIES")]/'
-                'following-sibling::*[self::table | self::form]//tr')
+        path = (
+            '//comment()[contains(., "DOCKET ENTRIES")]/'
+            "following-sibling::*[self::table | self::form]//tr"
+        )
         docket_entry_rows = self.tree.xpath(path)
 
         docket_entries = []
         for row in docket_entry_rows:
             de = {}
-            cells = row.xpath(u'./td')
+            cells = row.xpath(u"./td")
             if len(cells) == 1:
-                if cells[0].text_content() == 'No docket entries found.':
+                if cells[0].text_content() == "No docket entries found.":
                     break
                 continue
 
             date_filed_str = force_unicode(cells[0].text_content())
-            de[u'date_filed'] = convert_date_string(date_filed_str)
-            de[u'document_number'] = self._get_document_number(cells[1])
-            de[u'pacer_doc_id'] = self._get_pacer_doc_id(cells[1])
-            if not de[u'document_number']:
-                if de[u'pacer_doc_id']:
+            de[u"date_filed"] = convert_date_string(date_filed_str)
+            de[u"document_number"] = self._get_document_number(cells[1])
+            de[u"pacer_doc_id"] = self._get_pacer_doc_id(cells[1])
+            if not de[u"document_number"]:
+                if de[u"pacer_doc_id"]:
                     # If we lack the document number, but have
                     # the pacer ID, use it.
-                    de[u'document_number'] = de[u'pacer_doc_id']
+                    de[u"document_number"] = de[u"pacer_doc_id"]
                 else:
                     # We lack both the document number and the pacer ID.
                     # Probably a minute order. No need to set either.
                     pass
-            de[u'description'] = force_unicode(cells[2].text_content())
+            de[u"description"] = force_unicode(cells[2].text_content())
             docket_entries.append(de)
 
-        docket_entries = clean_pacer_object(docket_entries)
+        docket_entries = clean_court_object(docket_entries)
         self._docket_entries = docket_entries
         return docket_entries
 
     @staticmethod
     def _get_document_number(cell):
         """Get the document number"""
-        text_nodes = cell.xpath('.//text()[not(parent::font)]')
+        text_nodes = cell.xpath(".//text()[not(parent::font)]")
         text_nodes = map(clean_string, text_nodes)
         for text_node in text_nodes:
             if text_node.isdigit():
@@ -545,12 +586,12 @@ class AppellateDocketReport(BaseDocketReport, BaseReport):
 
     @staticmethod
     def _get_pacer_doc_id(cell):
-        urls = cell.xpath(u'.//a')
+        urls = cell.xpath(u".//a")
         if not urls:
             # Entry exists but lacks a URL. Probably a minute order or similar.
             return None
         else:
-            doc1_url = urls[0].xpath('./@href')[0]
+            doc1_url = urls[0].xpath("./@href")[0]
             return get_pacer_doc_id_from_doc1_url(doc1_url)
 
     def _get_case_name(self):
@@ -561,10 +602,12 @@ class AppellateDocketReport(BaseDocketReport, BaseReport):
         # 3: as long as there is boldface in the first row of the table.
         # 4: Within that table, take the cell that doesn't have any bold.
 
-        path = ('//comment()[contains(., "NEW SECTION - Case Stub")]/'  # 1
-                'following-sibling::*//table[1]'  # 2
-                '[.//tr[1]//b]//'  # 3
-                'td[not(.//b)]')  # 4
+        path = (
+            '//comment()[contains(., "NEW SECTION - Case Stub")]/'  # 1
+            "following-sibling::*//table[1]"  # 2
+            "[.//tr[1]//b]//"  # 3
+            "td[not(.//b)]"
+        )  # 4
 
         case_name = self.tree.xpath(path)[0].text_content()
         return clean_string(harmonize(case_name))
@@ -578,23 +621,25 @@ class AppellateDocketReport(BaseDocketReport, BaseReport):
             # No panel table.
             return []
 
-        panel_string = self._get_tail_by_regex('Panel:', node=panel_table)
-        if panel_string in ['', "Not available"]:
+        panel_string = self._get_tail_by_regex("Panel:", node=panel_table)
+        if panel_string in ["", "Not available"]:
             return []
         else:
             return panel_string.split()
 
     def _get_case_type_info(self):
         """Get the case type information and return it as a csv string"""
-        path = ('//*[re:match(text(), "Case Type Information")]/'
-                'ancestor::table[1]//b')
+        path = (
+            '//*[re:match(text(), "Case Type Information")]/'
+            "ancestor::table[1]//b"
+        )
         bold_nodes = self.tree.re_xpath(path)
         case_info = []
         for node in bold_nodes:
             tail = str(node.tail).strip()
-            if not any([tail == 'None', tail == 'null', tail == '-']):
+            if not any([tail == "None", tail == "null", tail == "-"]):
                 case_info.append(node.tail)
-        return ', '.join(case_info)
+        return ", ".join(case_info)
 
     def _get_originating_court_info(self):
         """Get all of the originating type information as a dict."""
@@ -612,14 +657,14 @@ class AppellateDocketReport(BaseDocketReport, BaseReport):
         )[0].text_content()
         m = self.docket_number_dist_regex.search(docket_number_node_str)
         if m:
-            ogc_info[u'docket_number'] = m.group(1)
+            ogc_info[u"docket_number"] = m.group(1)
         else:
             # Regex didn't match. Try another way. Seems to happen
             # when the OGC is a case that wasn't in a normal district
             # court. E.g. BIA.
             #   <B>District: </B>BIA-1 : A999-999-999
-            docket_number = docket_number_node_str.split(':')[2].strip()
-            ogc_info[u'docket_number'] = docket_number
+            docket_number = docket_number_node_str.split(":")[2].strip()
+            ogc_info[u"docket_number"] = docket_number
 
         # Alien numbers are somewhat like social security numbers for
         # non-citizens, and attorneys generally redact them from
@@ -630,48 +675,51 @@ class AppellateDocketReport(BaseDocketReport, BaseReport):
         # best not to do so on CL without a paywall.
         #
         # Place them in their own field so we can restrict access to them
-        if re.match(r'A[0-9-]+', ogc_info[u'docket_number']):
-            ogc_info[u'RESTRICTED_ALIEN_NUMBER'] = ogc_info.pop(
-                u'docket_number')
+        if re.match(r"A[0-9-]+", ogc_info[u"docket_number"]):
+            ogc_info[u"RESTRICTED_ALIEN_NUMBER"] = ogc_info.pop(
+                u"docket_number"
+            )
 
         try:
-            og_court_url = ogc_table.xpath('.//a/@href')[0]
+            og_court_url = ogc_table.xpath(".//a/@href")[0]
         except IndexError:
             # Happens when dockets don't link to their OGC.
-            ogc_info[u'court_id'] = u''
+            ogc_info[u"court_id"] = u""
         else:
-            ogc_info[u'court_id'] = get_court_id_from_url(og_court_url)
+            ogc_info[u"court_id"] = get_court_id_from_url(og_court_url)
 
-        judge_str = self._get_tail_by_regex('Trial Judge')
+        judge_str = self._get_tail_by_regex("Trial Judge")
         if judge_str:
-            ogc_info[u'assigned_to'] = normalize_judge_string(judge_str)[0]
+            ogc_info[u"assigned_to"] = normalize_judge_string(judge_str)[0]
 
-        ogc_info[u'court_reporter'] = self._get_tail_by_regex('Court Reporter')
-        ogc_info[u'date_filed'] = self._get_tail_by_regex('Date Filed', True)
-        ogc_info[u'date_disposed'] = self._get_tail_by_regex(
-            'Date Disposed', True)
-        ogc_info[u'disposition'] = self._get_tail_by_regex('Disposition')
+        ogc_info[u"court_reporter"] = self._get_tail_by_regex("Court Reporter")
+        ogc_info[u"date_filed"] = self._get_tail_by_regex("Date Filed", True)
+        ogc_info[u"date_disposed"] = self._get_tail_by_regex(
+            "Date Disposed", True
+        )
+        ogc_info[u"disposition"] = self._get_tail_by_regex("Disposition")
 
-        trial_judge_str = self._get_tail_by_regex('Trial Judge')
-        ogc_info[u'assigned_to'] = normalize_judge_string(trial_judge_str)[0]
-        order_judge_str = self._get_tail_by_regex('Ordering Judge')
-        ogc_info[u'ordering_judge'] = normalize_judge_string(
-            order_judge_str)[0]
+        trial_judge_str = self._get_tail_by_regex("Trial Judge")
+        ogc_info[u"assigned_to"] = normalize_judge_string(trial_judge_str)[0]
+        order_judge_str = self._get_tail_by_regex("Ordering Judge")
+        ogc_info[u"ordering_judge"] = normalize_judge_string(order_judge_str)[
+            0
+        ]
 
-        date_labels = ogc_table.xpath('.//tr[last() - 1]/td//text()')
-        dates = ogc_table.xpath('.//tr[last()]/td//text()')
+        date_labels = ogc_table.xpath(".//tr[last() - 1]/td//text()")
+        dates = ogc_table.xpath(".//tr[last()]/td//text()")
         for label, date in zip(date_labels, dates):
             label = clean_string(label)
             date = clean_string(date)
-            if label == 'Date Order/Judgment:':
-                ogc_info[u'date_judgment'] = convert_date_string(date)
-            if label == 'Date Order/Judgment EOD:':
-                ogc_info[u'date_judgment_eod'] = convert_date_string(date)
+            if label == "Date Order/Judgment:":
+                ogc_info[u"date_judgment"] = convert_date_string(date)
+            if label == "Date Order/Judgment EOD:":
+                ogc_info[u"date_judgment_eod"] = convert_date_string(date)
             # NOA: Notice of appeal
-            if label == 'Date NOA Filed:':
-                ogc_info[u'date_filed_noa'] = convert_date_string(date)
+            if label == "Date NOA Filed:":
+                ogc_info[u"date_filed_noa"] = convert_date_string(date)
             if label == "Date Rec'd COA:":
-                ogc_info[u'date_received_coa'] = convert_date_string(date)
+                ogc_info[u"date_received_coa"] = convert_date_string(date)
         return ogc_info
 
     def _get_tail_by_regex(self, regex, cast_to_date=False, node=None):
@@ -692,7 +740,7 @@ class AppellateDocketReport(BaseDocketReport, BaseReport):
             if cast_to_date:
                 return None
             else:
-                return ''
+                return ""
         else:
             if cast_to_date:
                 return convert_date_string(tail)
@@ -705,11 +753,12 @@ def _main():
         print("Please provide a path to an HTML file to parse.")
         sys.exit(1)
     report = AppellateDocketReport(
-        'ca9')  # Court ID is only needed for querying.
+        "ca9"
+    )  # Court ID is only needed for querying.
     filepath = sys.argv[1]
     print("Parsing HTML file at {}".format(filepath))
-    with open(filepath, 'r') as f:
-        text = f.read().decode('utf-8')
+    with open(filepath, "r") as f:
+        text = f.read().decode("utf-8")
     report._parse_text(text)
     pprint.pprint(report.data, indent=2)
 
