@@ -132,14 +132,24 @@ class BaseReport(object):
         get the PDF itself ('1').
         :return the Request.response object and the url queried
         """
-        timeout = (60, 300)
         url = make_doc1_url(self.court_id, pacer_doc_id, True)
         data = {
-            "case_id": pacer_case_id,
+            "caseid": pacer_case_id,
             "got_receipt": got_receipt,
+            # Include the PDF header where possible. Different courts allow
+            # different things here. Some have the toggle on the Docket Report
+            # page to allow headers, others do not. The ones that do not *seem*
+            # to default to including the headers. There's also a setting in
+            # ECF accounts that you can toggle to always include headers, but
+            # it's entirely unclear how it interacts with the per-docket
+            # settings. Anyway, we aggressively turn on the headers without an
+            # option to turn them off atm.
+            "pdf_header": "1",
+            "pdf_toggle_possible": "1",
         }
-        logger.info("GETting URL: %s with params: %s" % (url, data))
-        r = self.session.get(url, params=data, timeout=timeout)
+        timeout = (60, 300)
+        logger.info("POSTing URL: %s with params: %s" % (url, data))
+        r = self.session.post(url, data=data, timeout=timeout)
         return r, url
 
     def download_pdf(self, pacer_case_id, pacer_doc_id):
